=======
Changes
=======

v0.8.0
------

 * use cryptographically secure pseudo-random number generator if available.
 * added standard imports to help with python2/3 compatibility.

v0.7.0
------

 * added -t|--times N to allow generating multiple passphrases w/ one command.

v0.6.8
------

 * include CHANGES.rst and README.rst in sdist via MANIFEST.in

v0.6.7
------

 * cosmetic changes for better PyPI display


v0.6.6
------

 * cosmetic changes for better PyPI display


v0.6.4
-------

 * cosmetic changes for better PyPI display


v0.6.2
------

 * added -q option to omit extra information about how many unique candidate
   words were found and how many passphrases were possible
 * fix for --ascii option not being used, and improved encoding handling
 * start documenting changes in CHANGES.rst
 * use README and CHANGES as long_description for improved pypi info
